# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('cms', '0016_auto_20160608_1535'),
    ]

    operations = [
        migrations.CreateModel(
            name='Maps',
            fields=[
                ('cmsplugin_ptr', models.OneToOneField(related_name='djangocms_maps_maps', primary_key=True, to='cms.CMSPlugin', serialize=False, parent_link=True, auto_created=True)),
                ('map_provider', models.CharField(verbose_name='map provider', max_length=16, choices=[('mapbox', 'Mapbox OSM (API key required)'), ('bingmaps', 'Bing Maps (API key required)'), ('googlemaps', 'Google Maps (API key required)'), ('here', 'HERE WeGo (API key required)'), ('viamichelin', 'ViaMichelin (API key required)')], default='mapbox')),
                ('title', models.CharField(verbose_name='map title', max_length=100, null=True, blank=True)),
                ('address', models.CharField(verbose_name='address', max_length=150)),
                ('zipcode', models.CharField(verbose_name='zip code', max_length=30)),
                ('city', models.CharField(verbose_name='city', max_length=100)),
                ('content', models.CharField(help_text='Displayed under address in the bubble.', verbose_name='additional content', max_length=255, blank=True)),
                ('style', models.TextField(help_text='Provide a valid JSON configuration (escaped). See developers.google.com/maps/documentation/javascript/styling', verbose_name='custom map style', blank=True)),
                ('zoom', models.PositiveSmallIntegerField(verbose_name='zoom level', default=13, choices=[(0, '0'), (1, '1'), (2, '2'), (3, '3'), (4, '4'), (5, '5'), (6, '6'), (7, '7'), (8, '8'), (9, '9'), (10, '10'), (11, '11'), (12, '12'), (13, '13'), (14, '14'), (15, '15'), (16, '16'), (17, '17'), (18, '18'), (19, '19'), (20, '20'), (21, '21')])),
                ('lat', models.DecimalField(help_text='Use latitude & longitude to fine tune the map position.', blank=True, verbose_name='latitude', null=True, max_digits=10, decimal_places=6)),
                ('lng', models.DecimalField(verbose_name='longitude', max_digits=10, null=True, blank=True, decimal_places=6)),
                ('route_planer_title', models.CharField(verbose_name='route planner title', max_length=150, null=True, blank=True, default='Calculate your fastest way to here')),
                ('route_planer', models.BooleanField(verbose_name='route planner', default=False)),
                ('width', models.CharField(help_text='Plugin width (in px, em, %).', verbose_name='width', max_length=6, default='100%')),
                ('height', models.CharField(help_text='Plugin height (in px, em).', verbose_name='height', max_length=6, default='400px')),
                ('info_window', models.BooleanField(help_text='Show textbox over marker', verbose_name='info window', default=True)),
                ('scrollwheel', models.BooleanField(help_text='Enable scrollwheel zooming on the map', verbose_name='scrollwheel', default=True)),
                ('double_click_zoom', models.BooleanField(verbose_name='double click zoom', default=True)),
                ('draggable', models.BooleanField(verbose_name='draggable', default=True)),
                ('keyboard_shortcuts', models.BooleanField(verbose_name='keyboard shortcuts', default=True)),
                ('pan_control', models.BooleanField(verbose_name='Pan control', default=True)),
                ('zoom_control', models.BooleanField(verbose_name='zoom control', default=True)),
                ('street_view_control', models.BooleanField(verbose_name='Street View control', default=True)),
            ],
            options={
                'abstract': False,
            },
            bases=('cms.cmsplugin',),
        ),
    ]



#!/usr/bin/env python
# -*- coding: utf-8 -*-

from os.path import abspath, dirname, join
from setuptools import setup

import djangocms_maps as package

CLASSIFIERS = [
    'Development Status :: 4 - Beta',
    'Environment :: Web Environment',
    'Framework :: Django',
    'Intended Audience :: Developers',
    'License :: OSI Approved :: BSD License',
    'Operating System :: OS Independent',
    'Programming Language :: Python',
    'Topic :: Communications',
    'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    'Topic :: Internet :: WWW/HTTP :: Dynamic Content :: Message Boards',
    'Programming Language :: Python :: 2',
    'Programming Language :: Python :: 2.7',
    'Programming Language :: Python :: 3',
    'Programming Language :: Python :: 3.3',
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
]


def read(*pathcomponents):
    """Read the contents of a file located relative to setup.py"""
    with open(join(abspath(dirname(__file__)), *pathcomponents)) as thefile:
        return thefile.read()


setup(
    name='djangocms-maps',
    version=package.__version__,
    description=package.__doc__,
    author='Peter Bittner',
    author_email='django@bittner.it',
    url='https://github.com/Organice/djangocms-maps',
    packages=[
        'djangocms_maps',
        'djangocms_maps.migrations',
    ],
    license='BSD License',
    platforms=['OS Independent'],
    classifiers=CLASSIFIERS,
    long_description='\n'.join([read('README.rst'), read('CHANGELOG.rst')]),
    include_package_data=True,
    zip_safe=False
)



from django.utils.translation import ugettext_lazy as _

from cms.plugin_base import CMSPluginBase
from cms.plugin_pool import plugin_pool

from .forms import MapsForm
from .models import Maps
from .settings import API_KEYS


class MapsPlugin(CMSPluginBase):
    model = Maps
    name = _("Maps")
    render_template = "djangocms_maps/maps.html"
    admin_preview = False
    form = MapsForm
    fieldsets = (
        (None, {
            'fields': (
                'title',
                ('address', 'city'),
                ('zipcode', 'zoom',),
                'content',
                ('lat', 'lng'),
            ),
        }),
        (_('Advanced'), {
            'fields': (
                ('map_provider', 'info_window'),
                ('width', 'height'),
                # ('route_planer', 'route_planer_title'),
                ('scrollwheel', 'double_click_zoom', 'draggable',
                 'keyboard_shortcuts'),
                ('pan_control', 'zoom_control', 'street_view_control'),
                'style',
            ),
        }),
    )

    def render(self, context, instance, placeholder):
        context.update({
            'api_key': API_KEYS[instance.map_provider],
            'object': instance,
            'placeholder': placeholder,
        })
        return context


plugin_pool.register_plugin(MapsPlugin)



"""
Default settings for djangcms_maps
"""
from django.conf import settings
from django.utils.translation import ugettext_lazy as _

BINGMAPS_API_KEY = getattr(settings, 'MAPS_BINGMAPS_API_KEY', '')
GOOGLEMAPS_API_KEY = getattr(settings, 'MAPS_GOOGLEMAPS_API_KEY', '')
HERE_API_KEY = getattr(settings, 'MAPS_HERE_API_KEY', '')
MAPBOX_API_KEY = getattr(settings, 'MAPS_MAPBOX_API_KEY', '')
VIAMICHELIN_API_KEY = getattr(settings, 'MAPS_VIAMICHELIN_API_KEY', '')

API_KEYS = {
    'bingmaps': BINGMAPS_API_KEY,
    'googlemaps': GOOGLEMAPS_API_KEY,
    'here': HERE_API_KEY,
    'mapbox': MAPBOX_API_KEY,
    'viamichelin': VIAMICHELIN_API_KEY,
}

PROVIDERS = getattr(settings, 'MAPS_PROVIDERS', [
    ('mapbox', _('Mapbox OSM (API key required)')),
    ('bingmaps', _('Bing Maps (API key required)')),
    ('googlemaps', _('Google Maps (API key required)')),
    ('here', _('HERE WeGo (API key required)')),
    ('viamichelin', _('ViaMichelin (API key required)')),
])
